==> 1.0.74+1.tar.gz: lib/components/UikHomeCardTen.dart <==
// ignore: file_names
import 'package:ui_sdk/StandardPage.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikHomeCardThreeProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';
import 'package:flutter/material.dart';
import 'package:ui_sdk/utils/pubsub/localpubsub.dart';

import '../props/UikHomeCardTenProps.dart';

class UikHomeCardTen extends UikWidget {
  WidgetType _widgetType;
  UikHomeCardTenProps _uikHomeCardTenProps;
  UikHomeCardTen(this._widgetType, this._uikHomeCardTenProps)
      : super(_widgetType, _uikHomeCardTenProps);

  @override
  _UikHomeCardTenState createState() =>
      _UikHomeCardTenState(_uikHomeCardTenProps);
}

class _UikHomeCardTenState extends State<UikHomeCardTen> {
  UikHomeCardTenProps _uikHomeCardTenProps;
  _UikHomeCardTenState(this._uikHomeCardTenProps);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
        onTap: () async {
          print(_uikHomeCardTenProps.action.tap.type);
          PubSub pubsub = PubSub();
          await executeUikWidgetAction(_uikHomeCardTenProps.action);
        },
        child: Container(
          // decoration: BoxDecoration(
          //     border: Border.all(
          //   color: Colors.blue,
          // )),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              (_uikHomeCardTenProps.image != null)
                  ? _uikHomeCardTenProps.image!
                  : const Text(""),
              const SizedBox(
                height: 7,
              ),
              _uikHomeCardTenProps.text!,
            ],
          ),
        ));
  }
}

==> 1.0.75+1.tar.gz: lib/components/UikHomeCardTen.dart <==
// ignore: file_names
import 'package:ui_sdk/StandardPage.dart';
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import 'package:ui_sdk/props/UikHomeCardThreeProps.dart';
import 'package:ui_sdk/utils/UikActionListner.dart';
import 'package:flutter/material.dart';
import 'package:ui_sdk/utils/pubsub/localpubsub.dart';

import '../props/UikHomeCardTenProps.dart';

class UikHomeCardTen extends UikWidget {
  WidgetType _widgetType;
  UikHomeCardTenProps _uikHomeCardTenProps;
  UikHomeCardTen(this._widgetType, this._uikHomeCardTenProps)
      : super(_widgetType, _uikHomeCardTenProps);

  @override
  _UikHomeCardTenState createState() =>
      _UikHomeCardTenState(_uikHomeCardTenProps);
}

class _UikHomeCardTenState extends State<UikHomeCardTen> {
  UikHomeCardTenProps _uikHomeCardTenProps;
  _UikHomeCardTenState(this._uikHomeCardTenProps);

  @override
  Widget build(BuildContext context) {
    return InkWell(
        onTap: () async {
          print(_uikHomeCardTenProps.action.tap.type);
          PubSub pubsub = PubSub();
          await executeUikWidgetAction(_uikHomeCardTenProps.action);
        },
        child: Container(
          // decoration: BoxDecoration(
          //     border: Border.all(
          //   color: Colors.blue,
          // )),
          child: Column(
            // mainAxisAlignment: MainAxisAlignment.center,
            children: [
              (_uikHomeCardTenProps.image != null)
                  ? _uikHomeCardTenProps.image!
                  : const Text(""),
              const SizedBox(
                height: 7,
              ),
              _uikHomeCardTenProps.text!,
            ],
          ),
        ));
  }
}
